

# go4py

# TODO
 - [] Warn the user if it uses string or other dynamicly allocated types as result
 - [] unexported function warn + export with space (`// export`) 
 - [] python type definition file
